@@ -2,10 +2,12 @@
 infer frequencies of mutations or clades
 """
 import json, os, sys
+import datetime
 import numpy as np
 from collections import defaultdict
 from Bio import Phylo, AlignIO
 from Bio.Align import MultipleSeqAlignment
+import treetime.utils
 
 from .frequency_estimators import get_pivots, alignment_frequencies, tree_frequencies
 from .frequency_estimators import AlignmentKdeFrequencies, TreeKdeFrequencies, TreeKdeFrequenciesError
@@ -21,11 +23,13 @@ def register_arguments(parser):
     parser.add_argument('--regions', type=str, nargs='+', default=['global'],
                         help="region to subsample to")
     parser.add_argument("--pivot-interval", type=int, default=3,
-                        help="number of months between pivots")
-    parser.add_argument('--min-date', type=float,
-                        help="minimal pivot value")
-    parser.add_argument('--max-date', type=float,
-                        help="maximal pivot value")
+                        help="number of units between pivots")
+    parser.add_argument("--pivot-interval-units", type=str, default="months", choices=['months', 'weeks'],
+                        help="space pivots by months (default) or by weeks")
+    parser.add_argument('--min-date', type=numeric_date,
+                        help="date to begin frequencies calculations; may be specified as an Augur-style numeric date (with the year as the integer part) or YYYY-MM-DD")
+    parser.add_argument('--max-date', type=numeric_date,
+                        help="date to end frequencies calculations; may be specified as an Augur-style numeric date (with the year as the integer part) or YYYY-MM-DD")
 
     # Tree-specific arguments
     parser.add_argument('--tree', '-t', type=str,
@@ -104,7 +108,7 @@ def run(args):
 
         if args.method == "diffusion":
             # estimate tree frequencies
-            pivots = get_pivots(tps, args.pivot_interval, args.min_date, args.max_date)
+            pivots = get_pivots(tps, args.pivot_interval, args.min_date, args.max_date, args.pivot_interval_units)
             frequency_dict = {"pivots":format_frequencies(pivots)}
             frequency_dict["counts"] = {}
 
@@ -157,6 +161,7 @@ def run(args):
                 pivot_frequency=args.pivot_interval,
                 start_date=args.min_date,
                 end_date=args.max_date,
+                pivot_interval_units=args.pivot_interval_units,
                 weights=weights,
                 weights_attribute=weights_attribute,
                 include_internal_nodes=args.include_internal_nodes,
@@ -190,7 +195,7 @@ def run(args):
             tps = np.array([np.mean(dates[seq.name]) for seq in aln])
 
             if frequencies is None:
-                pivots = get_pivots(tps, args.pivot_interval, args.min_date, args.max_date)
+                pivots = get_pivots(tps, args.pivot_interval, args.min_date, args.max_date, args.pivot_interval_units)
                 frequencies = {"pivots":format_frequencies(pivots)}
 
             if args.method == "kde":
@@ -201,6 +206,7 @@ def run(args):
                     pivot_frequency=args.pivot_interval,
                     start_date=args.min_date,
                     end_date=args.max_date,
+                    pivot_interval_units=args.pivot_interval_units,
                     weights=weights,
                     weights_attribute=weights_attribute,
                     include_internal_nodes=args.include_internal_nodes,
@@ -224,3 +230,19 @@ def run(args):
 
         write_json(frequencies, args.output)
         print("mutation frequencies written to", args.output, file=sys.stdout)
+
+
+def numeric_date(date):
+    """
+    Converts the given *date* string to a :py:class:`float`.
+    *date* may be given as a number (a float) with year as the integer part, or
+    in the YYYY-MM-DD (ISO 8601) syntax.
+    >>> numeric_date("2020.42")
+    2020.42
+    >>> numeric_date("2020-06-04")
+    2020.42486...
+    """
+    try:
+        return float(date)
+    except ValueError:
+        return treetime.utils.numeric_date(datetime.date(*map(int, date.split("-", 2))))
